@@ -137,7 +137,9 @@ class Instance(Entity, ServiceMixin):
             return self.ready()
         else:
             log.debug('Getting instance attribute: %s' % key)
-            return self.json()[key]
+            atr = self.json()[key]
+            log.debug(atr)
+            return atr
 
     def _cache_free(self):
         """Frees cache"""
@@ -166,13 +168,13 @@ class Instance(Entity, ServiceMixin):
     @staticmethod
     def new(application, revision=None, environment=None, name=None, parameters=None, submodules=None, destroyInterval=None):
 
+        if not environment:
+            environment = application.organization.defaultEnvironment
         if not parameters: parameters = {}
         conf = {}
         conf['parameters'] = parameters
-        if environment:  # if environment set, it overrides parameter
-            conf['environmentId'] = environment.environmentId
-        elif not 'environmentId' in parameters.keys():  # if not set and not in params, use default
-            conf['environmentId'] = application.organization.defaultEnvironment.environmentId
+        conf['environmentId'] = environment.environmentId
+
         if name:
             conf['instanceName'] = name
         if destroyInterval:
@@ -180,13 +182,18 @@ class Instance(Entity, ServiceMixin):
         if revision:
             conf['revisionId'] = revision.id
         conf['submodules'] = submodules or {}
-        log.info("Creating instance: %s" % name)
+        log.info("Starting instance: %s\n    Application: %s (%s)\n    Environment: %s (%s)\n    Submodules: %s\n    destroyInterval: %s" %
+                 (name,
+                  application.name, application.applicationId,
+                  environment.name, environment.environmentId,
+                  submodules, destroyInterval))
         log.debug("Instance configuration: %s" % conf)
         data = json.dumps(conf)
         before_creation = time.gmtime(time.time())
         resp = router.post_organization_instance(org_id=application.organizationId, app_id=application.applicationId, data=data)
         instance = Instance(organization=application.organization, id=resp.json()['id'])
         instance._last_workflow_started_time = before_creation
+        log.debug("Instance %s (%s) started." % (instance.name, instance.id))
         return instance
 
     def ready(self, timeout=3):  # Shortcut for convinience. Timeout = 3 min (ask timeout*6 times every 10 sec)
@@ -199,7 +206,8 @@ class Instance(Entity, ServiceMixin):
 
     def run_workflow(self, name, parameters=None):
         if not parameters: parameters = {}
-        log.info("Running workflow %s" % name)
+        log.info("Running workflow %s on instance %s (%s)" % (name, self.name, self.id))
+        log.debug("Parameters: %s" % parameters)
         self._last_workflow_started_time = time.gmtime(time.time())
         router.post_instance_workflow(org_id=self.organizationId, instance_id=self.instanceId, wf_name=name, data=json.dumps(parameters))
         return True
@@ -207,6 +215,20 @@ class Instance(Entity, ServiceMixin):
     #alias
     run_command = run_workflow
 
+    def schedule_workflow(self, name, timestamp, parameters=None):
+        if not parameters: parameters = {}
+        log.info("Scheduling workflow %s on instance %s (%s), timestamp: %s" % (name, self.name, self.id, timestamp))
+        log.debug("Parameters: %s" % parameters)
+        payload = {'parameters': parameters, 'timestamp':timestamp}
+        router.post_instance_workflow_schedule(org_id=self.organizationId, instance_id=self.instanceId, wf_name=name, data=json.dumps(payload))
+        return True
+
+    def reschedule_workflow(self, workflow_id, timestamp):
+        log.info("ReScheduling workflow %s on instance %s (%s), timestamp: %s" % (workflow_id, self.name, self.id, timestamp))
+        payload = {'timestamp':timestamp}
+        router.post_instance_reschedule(org_id=self.organizationId, instance_id=self.instanceId, workflow_id=workflow_id, data=json.dumps(payload))
+        return True
+
     def get_manifest(self):
         return router.post_application_refresh(org_id=self.organizationId, app_id=self.applicationId).json()
 
@@ -232,7 +254,14 @@ class Instance(Entity, ServiceMixin):
         return router.put_instance_configuration(org_id=self.organizationId, instance_id=self.instanceId, data=payload)
 
     def force_remove(self):
-        return router.delete_organizaton_instance_force(org_id=self.organizationId, instance_id=self.instanceId)
+        return router.delete_instance_force(org_id=self.organizationId, instance_id=self.instanceId)
+
+    def cancel_command(self):
+        return router.post_instance_action(org_id=self.organizationId, instance_id=self.instanceId, action="cancel")
+    def star(self):
+        return router.post_instance_action(org_id=self.organizationId, instance_id=self.instanceId, action="star")
+    def unstar(self):
+        return router.post_instance_action(org_id=self.organizationId, instance_id=self.instanceId, action="unstar")
 
     def delete(self):
         self.destroy()
@@ -240,7 +269,7 @@ class Instance(Entity, ServiceMixin):
         return True
 
     def destroy(self):
-        log.info("Destroying instance %s" % self.name)
+        log.info("Destroying instance %s (%s)" % (self.name, self.id))
         return self.run_workflow("destroy")
 
     @property
@@ -379,4 +408,4 @@ class activityLog(object):
         raise exceptions.NotFoundError('Activitylog interval not found: [%s , %s]' % (start_text, end_text))
 
     def sort(self):
-        self.log = sorted(self.log, key=lambda x: x['time'], reverse=False)
\ No newline at end of file
+        self.log = sorted(self.log, key=lambda x: x['time'], reverse=False)
