@@ -23,6 +23,7 @@ import yaml
 from qubell.api.private import exceptions
 from qubell.api.provider.router import ROUTER as router
 
+#ToDo: Move to Globals
 
 COBALT_SECURE_STORE_TYPE = 'builtin:cobalt_secure_store'
 WORKFLOW_SERVICE_TYPE = 'builtin:workflow_service'
@@ -59,7 +60,7 @@ class ServiceMixin(object):
         except:
             old = params[SHARED_INSTANCES_PARAMETER_NAME]
 
-        old[revision.revisionId.split('-')[0]] = instance.instanceId
+        old[revision.id] = instance.instanceId
         params[SHARED_INSTANCES_PARAMETER_NAME] = yaml.safe_dump(old, default_flow_style=False)
         self.reconfigure(parameters=params)
 
@@ -85,4 +86,11 @@ class ServiceMixin(object):
                     instance.name, self.name))
 
     def list_shared_instances(self):
-        return yaml.safe_load(self.parameters[SHARED_INSTANCES_PARAMETER_NAME])
\ No newline at end of file
+        return yaml.safe_load(self.parameters[SHARED_INSTANCES_PARAMETER_NAME])
+
+    @property
+    def is_secure_vault(self):
+        raw = self.json()
+        if 'templateId' in raw:
+            return raw['templateId'] == COBALT_SECURE_STORE_TYPE
+        return False
\ No newline at end of file
